/*
 *    main.cpp
 *
 *    Video nuoma
 *
 */
#include <iostream>
#include <iomanip>
#include <vector>
#include <climits>
using namespace std;
//------------------------------------------------------------
struct Movie
{
    string   name;
    int      year;
    string   format;  // "VHS", "DVD", "HD"
    double   dayPrice;
    int      rentedByCustomer;  // numeruosime nuo 1
    double   moneyEarned;
};
typedef vector<Movie> Movies;
//------------------------------------------------------------
struct Customer
{
    string   name;
    string   address;
    double   moneyEarned;
};
typedef vector<Customer> Customers;
//------------------------------------------------------------
void printMovies    (const Movies&     movies);
void printCustomers (const Customers&  customers);
void addMovie       (      Movies&     movies);
void addCustomer    (      Customers&  customers);
void rentMovie      (      Movies&     movies, Customers& customers);
void returnMovie    (      Movies&     movies);
//------------------------------------------------------------
void printMenu ()
{
    cout << endl
         << "Video nuoma:" << endl
         << "  1 - spausdinti filmus"     << endl
         << "  2 - prideti nauja filma"   << endl
         << "  3 - isnuomuoti klientui"   << endl
         << "  4 - filmas grazintas"      << endl
         << endl
         << "  5 - spausdinti klientus"   << endl
         << "  6 - prideti nauja klienta" << endl
         << endl
         << "  0 - baigti darba"   << endl;
}
//------------------------------------------------------------
int main ()
{
    Movies     movies;
    Customers  customers;
    
    for (;;)
    {
        cout << "\n----------------------------------------\n";
        cout << "(m - rodyti meniu) > ";
        string key;
        cin >> key;
             if (key == "0") return 0;
        else if (key == "m") printMenu      ();
        else if (key == "1") printMovies    (movies);
        else if (key == "2") addMovie       (movies);
        else if (key == "3") rentMovie      (movies, customers);
        else if (key == "4") returnMovie    (movies);
        else if (key == "5") printCustomers (customers);
        else if (key == "6") addCustomer    (customers);
        else cout << endl << "Neteisinga komanda..." << endl;   
    }
    
}
//------------------------------------------------------------
void printMovies    (const Movies&    movies)
{
    cout << "Filmu kiekis: " << movies.size() << endl;
    for (int i = 0;  i < movies.size();  i++)
    {
        cout << (i+1) 
             << ". "  << movies[i].rentedByCustomer
             << "\t"  << movies[i].format
             << " "   << movies[i].dayPrice << "Lt"
             << "\t(" << movies[i].moneyEarned << "Lt)"
             << "\t"  << movies[i].year
             << "\t"  << movies[i].name
             << endl;
    }                  
}
//------------------------------------------------------------
void printCustomers (const Customers& customers)
{
    cout << "Klietu kiekis: " << customers.size() << endl;
    for (int i = 0;  i < customers.size();  i++)
    {
        cout << (i+1) 
             << ". (" << customers[i].moneyEarned << "Lt)"
             << "\t"  << customers[i].name
             << " ("  << customers[i].address << ")"  
             << endl;
    }
}
//------------------------------------------------------------
void addMovie (Movies& movies)
{
    cin.ignore(INT_MAX, '\n'); // ignoruojam uzsilikusi klaviaturos ENTER
    Movie movie;
    cout << "Iveskite nauja filma:" << endl;
    cout << "    pavadinimas  : ";  getline(cin, movie.name);
    cout << "    metai        : ";  cin >> movie.year;
    cout << "    VHS/DVD/HD   : ";  cin >> movie.format;
    cout << "    kaina dienai : ";  cin >> movie.dayPrice;
    movie.rentedByCustomer =  0;
    movie.moneyEarned      =  0;
    movies.push_back(movie);   
}
//------------------------------------------------------------
void addCustomer (Customers& customers)
{
    cin.ignore(INT_MAX, '\n'); // ignoruojam uzsilikusi klaviaturos ENTER
    Customer customer;
    cout << "Iveskite nauja klienta:" << endl;
    cout << "    vardas : ";  getline(cin, customer.name);
    cout << "    adresas: ";  getline(cin, customer.address);
    customer.moneyEarned = 0;
    customers.push_back(customer);   
}
//------------------------------------------------------------
void rentMovie (Movies& movies, Customers& customers)
{
     int movieNo = 0;
     printMovies (movies);
     cout << "Iveskit filmo eiles numeri: ";
     cin  >> movieNo;
     if (movieNo <= 0  ||  movieNo > movies.size())
     {
         cout << "KLAIDA: nera filmo su ivestu eiles numeriu.";
         return;
     }
     if (movies[movieNo-1].rentedByCustomer != 0)
     {
         cout << "KLAIDA: filmas jau yra isnuomotas.";
         return;
     }
     
     int customerNo = 0;
     printCustomers (customers);
     cout << "Pasirinkite kliento eiles numeri: ";
     cin  >> customerNo;
     if (customerNo <= 0  ||  customerNo > customers.size())
     {
         cout << "KLAIDA: nera kliento su ivestu eiles numeriu.";
         return;
     }
     
     int dayCount;
     cout << "Keliom dienom nuomuosime        : ";
     cin  >> dayCount;     
     movies[movieNo-1].rentedByCustomer   = customerNo;
     movies[movieNo-1].moneyEarned       += dayCount * movies[movieNo-1].dayPrice;
     customers[customerNo-1].moneyEarned += dayCount * movies[movieNo-1].dayPrice;
}
//------------------------------------------------------------
void returnMovie    (Movies&     movies)
{
     int movieNo = 0;
     printMovies (movies);
     cout << "Iveskit filmo eiles numeri: ";
     cin  >> movieNo;
     if (movieNo <= 0  ||  movieNo > movies.size())
     {
         cout << "KLAIDA: nera filmo su ivestu eiles numeriu.";
         return;
     }
     movies[movieNo-1].rentedByCustomer = 0;
}
//============================================================
